@@ -1,4 +1,4 @@
-labelswitch <- function(Ki,per.to)
+ergmm.labelswitch <- function(Ki,per.to)
 {
   Ki.new <- Ki
   for(i in 1:length(per.to))
